from setuptools import setup, find_packages


setup(
    name='wilcox_utility_functions',
    version='0.0.1',
    author='Gregoyr Wilcox',
    author_email='wilcox12@canisius.edu',
    description='Tools for Greg Wilcox',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        ],
    python_requires='>=3.10',
)
